@@ -7,7 +7,6 @@ Created on 9 May 2022
 
 '''
 __all__ = ['algorMeter']
-__version__ = '0.9.4'
 __author__ = "Pietro d'Alessandro"
 
 import pandas as pd
@@ -28,7 +27,7 @@ def algorMeter(algorithms : list[Callable], problems : list[tuple[Callable,list[
     absTol : float =1.E-4, relTol : float = 1.E-5,  **kwargs) -> tuple[pd.DataFrame ,pd.DataFrame | np.ndarray] : 
     '''Benchmark environment for Optimizer algorithms
         - algorithms: algorithms list. *(algoList_simple is available )* 
-        - problems: problem list. See problems list in example4.py for syntax.   *(probList_base, probList_coax, probList_DCJBKM are available)*
+        - problems: problem list. See problems list in example4.py for syntax.   *(probList_base, probList_covx, probList_DCJBKM are available)*
         - tuneParameters = None: see tuneParameters section 
         - iterations = 500: max iterations number 
         - timeout = 180: time out in seconds
@@ -41,7 +40,7 @@ def algorMeter(algorithms : list[Callable], problems : list[tuple[Callable,list[
         - **kwargs: python kwargs propagated to algorithms
     '''
 
-    def algoRun (algorithm, experiment, **kwargs ):
+    def algoRun (algorithm, experiment, exceptionOn = False, **kwargs ):
         def checkTunePar(ls):
             if not ls:
                 return
@@ -89,28 +88,31 @@ def algorMeter(algorithms : list[Callable], problems : list[tuple[Callable,list[
         for dim in dims:
             algoDescr = prettyAlgo()
             print(f'Algorithm:{algoDescr}, Problem:{problem.__name__}, Dimension:{dim} ... running', end= '')
+            if tuneParameters:
+                print()
             ts = datetime.datetime.now()
             excp = None
             for varStat in scanParams(tuneParameters):
                 for _ in range(runs):
-                    p = problem (dimension=dim)  
-                    p.config(**kwargs)
+                    p = problem (dim, **kwargs)  
                     p.setLabel(algoDescr)
                     excp = None
                     try:
                         if runs > 1:
                             p.isRandomRun = True
+                        if tuneParameters:
+                            print(problem.__name__,str(varStat),end='\r')
                         algorithm(p, **kwargs)
                     except AssertionError as e:
                         raise e
                     except (ArithmeticError, Exception) as e:
                         excp = e
-                        if (dbprint or trace) and excp :
+                        counter.log (str(e), 'Error')
+                        if (exceptionOn or dbprint or trace) and excp :
                             raise e
                     finally:
                         if tuneParameters:
                             counter.log (str(varStat), 'Param')
-                            # print(str(varStat))
                         st = p.stats()
                         if excp: st['Status'] = 'Error'
                         stats.append(st)
@@ -119,7 +121,7 @@ def algorMeter(algorithms : list[Callable], problems : list[tuple[Callable,list[
             usedtime = datetime.datetime.now() - ts  
             msg = ': ' + str(excp) if excp else ''
             if tuneParameters:
-                print('. Done. time:',usedtime)
+                print('\ntime:',usedtime)
             else:
                 print('. Done. time:',usedtime, ' iterations:',iter, ' status:', st['Status'], msg)
 
@@ -137,7 +139,7 @@ def algorMeter(algorithms : list[Callable], problems : list[tuple[Callable,list[
         for alg in algorithms:
             dfl.append(algoRun(experiment=exp,algorithm=alg,tuneParameters = tuneParameters,
                 iterations=iterations, timeout = timeout, runs = runs, trace = trace, csv = csv, dbprint=dbprint,
-                absTol = absTol, relTol = relTol, savedata = savedata ))
+                absTol = absTol, relTol = relTol, savedata = savedata, **kwargs ))
 
     if not dfl:
         print('Empty result')
