@@ -76,22 +76,39 @@ class Kernel:
         return r, flags # flags is None if x not exist in cache
 
 ## problem interface
-    def __init__ (self, dimension : int =2) :
+    def __init__ (self, dimension : int , iterations : int =500, timeout : int = 180, trace : bool = False, savedata : bool = False,
+                csv :bool = False, relTol : float = 1.E-5, absTol : float = 1.E-8, **kwargs) :
         self.dimension = dimension 
         self.initCache(dimension)
         self.isRandomRun = False
         self.__inizialize__(dimension)
+        '''configure with default value'''
+        self.trace = trace
+        self.csv = csv
+        self.timeout = timeout
+        self.maxiterations = iterations
+        self.relTol = relTol 
+        self.absTol = absTol 
+        self.savedata = savedata
+        self.Xk = self.XStart
+
         self.randomSet() # default random run param
         self.label = ''
-        self.config() 
+        self.isf1_only = 'Kernel' in self._f2.__qualname__ and 'Kernel' in self._gf2.__qualname__
         self.K = -1
         self.Xk = self.XStart
         self.Xprev = self.Xk
         self.fXkPrev = math.inf
+        if self.savedata is True:
+            self.data = np.zeros([Kernel.SAVEDATABUFFERSIZE,self.dimension+1]) # +1 per fx
+            self.X = self.data[:,:-1] 
+            self.Y = self.data[:,-1] 
         self.clearCache()
         counter.reset()
         self.recalc(self.XStart)
 
+    
+
     def __inizialize__(self, dimension : int):
         self.optimumPoint = np.zeros(dimension)
         self.optimumValue = math.inf
@@ -170,22 +187,30 @@ class Kernel:
             return 
 
         fXk = self._f(self.Xk)
-        if self.fXkPrev > fXk:
-            CB = '\033[102m'
+        if self.K == 0:
+            CB = '\033[47m'
+            self.fXkPrev = fXk
+        elif self.fXkPrev > fXk:
+            CB = '\033[102m' # green
         else:
-            CB = '\033[103m'
+            CB = '\033[103m' # yellow
         CE = '\033[0m'
         
         if self.K == 0: print()
-        print(CB,f'{repr(self)} k:{self.K},f:{self._f(self.Xk):.3f},x:{self._pp(self.Xk)},gf:{self._pp(self._gf(self.Xk))},f1:{self._f1(self.Xk):.3f},gf1:{self._pp(self._gf1(self.Xk))},f2:{self._f2(self.Xk):.3f},gf2:{self._pp(self._gf2(self.Xk))}',CE)
+        if self.isf1_only:
+            print(CB,f'{self} k:{self.K},f:{self._f(self.Xk):.3f},x:{self._pp(self.Xk)},gf:{self._pp(self._gf(self.Xk))}',CE)
+        else:
+            print(CB,f'{self} k:{self.K},f:{self._f(self.Xk):.3f},x:{self._pp(self.Xk)},gf:{self._pp(self._gf(self.Xk))},f1:{self._f1(self.Xk):.3f},gf1:{self._pp(self._gf1(self.Xk))},f2:{self._f2(self.Xk):.3f},gf2:{self._pp(self._gf2(self.Xk))}',CE)
 
     def recalc(self,x):
         '''Recalc at step k
         '''
-        if not (self.Xk == self.Xprev).all:
-            self.fXkPrev = self.f(self.Xk)                
-            if self.fXkPrev > self.f(self.Xk):
-                self.fXkPrev = self.f(self.Xk)                
+        if not (self.Xk == self.Xprev).all():
+            self.fXkPrev = self._f(self.Xk)                
+            self.Xprev = self.Xk
+            # if self.fXkPrev > self.f(self.Xk):
+            #     self.fXkPrev = self.f(self.Xk)                
+        
         self.Xk = x
         self.Xkp1 = x
 
@@ -218,13 +243,13 @@ class Kernel:
             for self.K in range(1,self.maxiterations +1):
                 yield self.K
                 self.recalc(self.Xkp1)
-                if self.stop():
+                if callable(self.stop) and self.stop():
                     self.isFound = True
                     break
                 if  tm.default_timer() - self.startTime > self.timeout:
                     self.isTimeout = True
                     break
-                self.fXkPrev = self.f(self.Xk) 
+                self.fXkPrev = self._f(self.Xk) 
         finally:
             self.recalc(self.Xkp1)
             if  self.K <= self.maxiterations or self.stop():
@@ -245,9 +270,12 @@ class Kernel:
 
     def stop(self) -> bool:
         '''return True if experiment must stop. Override it if needed'''
-        if (self.Xk == self.Xprev).all:
+        if np.array_equal(self.Xk, self.Xprev): # if null step 
             return False
-        return bool(np.isclose(self.fXk,self.fXkPrev,rtol=self.relTol,atol=self.absTol) or np.allclose (self.gfXk,np.zeros(self.dimension),rtol=self.relTol,atol=self.absTol) )
+
+        rc = bool(np.isclose(self.fXk,self.fXkPrev,rtol=self.relTol,atol=self.absTol)  
+                  or np.allclose (self.gfXk,np.zeros(self.dimension),rtol=self.relTol,atol=self.absTol) )
+        return rc
 
     def isSuccess(self) -> bool:
         '''return True if experiment success. Override it if needed'''
@@ -259,6 +287,8 @@ class Kernel:
                 return 'Success'
             if self.isTimeout:
                 return 'Timeout'
+            if self.K == self.maxiterations:
+                return 'MaxIter'
             return 'Fail'
         counter.disable()
         stat = {"Problem" : str(self),
@@ -267,8 +297,8 @@ class Kernel:
                 "Iterations": int(self.K),
                 "f(XStar)": f'{float(self.f(self.XStar)):.7G}',
                 "f(BKXStar)":  f'{self.optimumValue:.7G}',
-                'Delta': f'{(abs(self.optimumValue-float(self.f(self.XStar)))):.0E}',
-                "Seconds" :f'{(tm.default_timer() - self.startTime):.2f}',
+                'Delta': f'{(abs(self.optimumValue-float(self.f(self.XStar)))):.2E}',
+                "Seconds" :f'{(tm.default_timer() - self.startTime):.4f}',
                 "XStar": self._pp(self.XStar),
                 "BKXStar":  self._pp(self.optimumPoint),
                 "Start point": self._pp(self.XStart),
@@ -291,7 +321,7 @@ class Kernel:
             raise ValueError('bad dimension')
         self.XStart = np.array(startPoint)
 
-    def randomSet(self, center = 0., size =1.):
+    def randomSet(self, center:float = 0., size: float = 1.) -> None:
         ''' set random run center and size'''
         self.startRandRect = np.array([center - size, center + size])
 
@@ -306,13 +336,16 @@ class Kernel:
         x = np.array(x)
         CB = '\033[102m'
         CE = '\033[0m'
-        print(CB,f'{repr(self)} at x:{self._pp(x)} -> f:{self._f(x):.3f},gf:{self._pp(self._gf(x))},f1:{self._f1(x):.3f},gf1:{self._pp(self._gf1(x))},f2:{self._f2(x):.3f},gf2:{self._pp(self._gf2(x))}',CE)
+        if self.isf1_only:
+            print(CB,f'{repr(self)} at x:{self._pp(x)} -> f:{self._f(x):.3f},gf:{self._pp(self._gf(x))}',CE)
+        else:
+            print(CB,f'{repr(self)} at x:{self._pp(x)} -> f:{self._f(x):.3f},gf:{self._pp(self._gf(x))},f1:{self._f1(x):.3f},gf1:{self._pp(self._gf1(x))},f2:{self._f2(x):.3f},gf2:{self._pp(self._gf2(x))}',CE)
 
     def __str__ (self):
-        return self.__class__.__name__  
+        return self.__class__.__name__
 
     def __repr__ (self):
-        return self.__class__.__name__ + "-" +str(self.dimension)
+        return super(Kernel, self).__repr__() + " Dimension:" +str(self.dimension)
   
     def setLabel(self,label):
         self.label = label
@@ -321,8 +354,7 @@ class Kernel:
     def _pp(s):
         r = np.array2string(s,precision=4,threshold=4)
         return r
-
-
+    
 # def sign(x):
 #     # return np.sign(x)
 #     if type(x) == np.ndarray:
