@@ -5,12 +5,11 @@ Kaisa Joki, Adil M. Bagirov, Napsu Karmitsa & Marko M. Mäkelä
 
 import numpy as np
 from algormeter.kernel import *
-from algormeter.tools import counter, dbx
 
 class JB01 (Kernel):
     def __inizialize__(self, dimension):
         if dimension != 2:
-            raise ValueError(f'Dimension {dimension} not supported ')
+            raise ValueError(f'{self}: dimension {dimension} not supported ')
         self.optimumPoint = np.array([1.,1.])
         self.optimumValue = 2.0
         self.XStart = np.array([2.,2.])
@@ -56,7 +55,7 @@ class JB01 (Kernel):
 class JB02 (Kernel):
     def __inizialize__(self, dimension):
         if dimension != 2:
-            raise ValueError(f'Dimension {dimension} not supported ')
+            raise ValueError(f'{self}: dimension {dimension} not supported ')
         self.XStart = np.array([-1.2,1.])
         self.optimumPoint = np.array([1.,1.])
         self.optimumValue = 0.0
@@ -76,7 +75,7 @@ class JB02 (Kernel):
 class JB03 (Kernel):
     def __inizialize__(self, dimension):
         if dimension != 4:
-            raise ValueError(f'Dimension {dimension} not supported ')
+            raise ValueError(f'{self}: dimension {dimension} not supported ')
         self.XStart = np.array([1.,3.,3.,1.])
         self.optimumPoint = np.array([1.,1.,1.,1.])
         self.optimumValue = 0.0
@@ -112,7 +111,7 @@ class JB04 (Kernel):
         return self.dimension * np.max(np.abs(x))
     
     def _f2(self,x ):
-        return np.sum(abs(x))
+        return np.sum(np.abs(x))
 
     def _gf1(self, x): 
         a = np.zeros (self.dimension)
@@ -129,15 +128,10 @@ class JB05 (Kernel):
         self.XStart[0] = 1./dimension #"bagirov OMS 2002.pdf"
         self.optimumPoint = np.ones(dimension)/self.dimension
         self.optimumValue = 0.0
+        self.tm = np.outer(np.arange(1,21)*0.05,np.ones(dimension)) ** np.arange(dimension)
 
     def ff(self,x):
-        r = np.zeros(20)
-        t = np.arange(1,21)*0.05
-
-        for j in range(20):
-            for i in range(self.dimension):
-                r[j] = r[j] + (x[i]-self.optimumPoint[i])*t[j]**i
-        return r
+        return self.tm @ (x - self.optimumPoint)
     
     def _f1(self,x):
         return 20*np.max(abs(self.ff(x)))
@@ -146,27 +140,18 @@ class JB05 (Kernel):
         return np.sum(abs(self.ff(x)))
 
     def _gf1(self,x):
-        v = np.zeros(self.dimension)
-        t = np.arange(1,21)*0.05
         r = self.ff(x)
         m = np.argmax(abs(r))
-        for i in range(v.size):
-            v[i] = sign(r[m])*t[m]**i
-        return 20*v
+        return 20*(self.tm[m] * np.sign(r[m])) 
 
     def _gf2(self,x):
-        v = np.zeros(self.dimension)
-        t = np.arange(1,21)*0.05
         r = self.ff(x)
-        for i in range(v.size):
-            for j in range(20):
-                v[i] = v[i] + sign(r[j])*t[j]**i
-        return v
+        return np.sign(r) @ self.tm  
 
 class JB06 (Kernel):
     def __inizialize__(self, dimension):
         if dimension != 2:
-            raise ValueError(f'Dimension {dimension} not supported ')
+            raise ValueError(f'{self}: dimension {dimension} not supported ')
         self.XStart = np.array([10.,1.])
         self.optimumPoint = np.array([5.,0.])
         self.optimumValue = -2.5
@@ -189,7 +174,7 @@ class JB06 (Kernel):
 class JB07 (Kernel):
     def __inizialize__(self, dimension):
         if dimension != 2:
-            raise ValueError(f'Dimension {dimension} not supported ')
+            raise ValueError(f'{self}: dimension {dimension} not supported ')
         self.XStart = np.array([-2.,1.])
         self.optimumPoint = np.array([.5,.5])
         self.optimumValue = 0.5
@@ -237,7 +222,7 @@ class JB07 (Kernel):
 class JB08 (Kernel):
     def __inizialize__(self, dimension):
         if dimension != 3:
-            raise ValueError(f'Dimension {dimension} not supported ')
+            raise ValueError(f'{self}: dimension {dimension} not supported ')
         self.XStart = np.array([.5,.5,.5])
         self.optimumPoint = np.array([.75,1.25,.25])
         self.optimumValue = 3.5
@@ -281,7 +266,7 @@ class JB08 (Kernel):
 class JB09 (Kernel):
     def __inizialize__(self, dimension):
         if dimension != 4:
-            raise ValueError(f'Dimension {dimension} not supported ')
+            raise ValueError(f'{self}: dimension {dimension} not supported ')
         self.XStart = np.array([4.,2.,4.,2])
         self.optimumPoint = np.array([7/3.,1./3,.5,2.])
         self.optimumValue = 11/6.
@@ -409,7 +394,7 @@ probList_DCJBKM = [ # number are X dimensions
             (JB01,[2]), 
             (JB02,[2]), 
             (JB03,[4]), 
-            (JB04,[2,5,10,50,100,150,200,250,350,500,750
+            (JB04,[2,5,10,50,100,150,200,250,500,750
                    ]),
             (JB05,[ 2,5,10,50, 100,150, 200 ,250,300,350,400,500,1000,1500,3000,10000,15000,20000,50000
                    ]),
